TOKEN = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VyX2lkIjoiMSIsImFwcF9pZCI6IjUiLCJyaWdodHMiOiI4MTkxIiwiYXBwX2tleSI6ImM2NjI3MTkyLTQzZjctNGMwZi1iYTc2LTZiZGEzMzIzYWE1NSIsImlhdCI6MTU5OTM5NDcxOCwiZXhwIjoxNjMwODQ0MzE4LCJqdGkiOiI2Y2U1MDgwMS00Mzg3LTQyNTAtYTZiMy1lNWZhMjE5OWM4Y2YifQ.0wVYJ6wrKM6bBEEnwnge-csK94KV9e15G9R2GJUPEQs'
APP_KEY = 'c6627192-43f7-4c0f-ba76-6bda3323aa55'
DEV_MODE = True
# token_without_permissions = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VyX2lkIjoiMSIsImFwcF9pZCI6IjUiLCJyaWdodHMiOiIwIiwiYXBwX2tleSI6ImM2NjI3MTkyLTQzZjctNGMwZi1iYTc2LTZiZGEzMzIzYWE1NSIsImlhdCI6MTU5OTM4NzU2NSwiZXhwIjoxNjMwODM3MTY1LCJqdGkiOiJkMDBiNGUyYi0yNDdjLTQ4OTMtYTQ3MS1hZGY2YTE4NzBlYTMifQ.q97Tk8YlIDF95O-8A1X4YJ57vEC9bZRDmJ7jsn0zZsY'
